@@ -4,6 +4,8 @@ Copyright (c) 2021, binary butterfly GmbH and contributors
 Use of this source code is governed by an MIT-style license that can be found in the LICENSE file.
 """
 
+from typing import Optional
+
 from validataclass.exceptions import ValidationError
 
 __all__ = [
@@ -15,7 +17,10 @@ __all__ = [
 
 class ValueNotAllowedError(ValidationError):
     """
-    Validation error raised by `AnyOfValidator` and `EnumValidator` when the input value is not an element in the specified list of
-    allowed values.
+    Validation error raised by `AnyOfValidator` and `EnumValidator` when the input value is not an element in the
+    specified list of allowed values.
     """
     code = 'value_not_allowed'
+
+    def __init__(self, *, allowed_values: Optional[list] = None, **kwargs):
+        super().__init__(allowed_values=allowed_values, **kwargs)
