@@ -6,15 +6,22 @@ Use of this source code is governed by an MIT-style license that can be found in
 
 import pytest
 
+from tests.test_utils import UNSET_PARAMETER
 from validataclass.exceptions import RequiredValueError, InvalidTypeError, NumberRangeError, InvalidIntegerError, \
     InvalidValidatorOptionException
 from validataclass.validators import IntegerValidator
 
 
 class IntegerValidatorTest:
+    """
+    Unit tests for IntegerValidator.
+    """
+
+    # General tests
+
     @staticmethod
     def test_valid_integer():
-        """ Test IntegerValidator with valid integers. """
+        """ Test default IntegerValidator with valid integers. """
         validator = IntegerValidator()
         assert validator.validate(0) == 0
         assert validator.validate(123) == 123
@@ -40,17 +47,34 @@ class IntegerValidatorTest:
             'expected_type': 'int',
         }
 
-    # Test value range requirement check
+    # Tests with and without value range requirements
 
     @staticmethod
     @pytest.mark.parametrize(
-        'min_value, max_value, input_data_list', [
+        'min_value, max_value, input_data_list',
+        [
+            # Use default min_value and max_value (allows 32 bit integers only)
+            (UNSET_PARAMETER, UNSET_PARAMETER, [-2147483648, -1, 0, 123, 2147483647]),
+
+            # Only set min_value, use default max_value
+            (-1000000000000000, UNSET_PARAMETER, [-1000000000000000, -2147483648, 0, 2147483647]),
+
+            # Only set max_value, use default min_value
+            (UNSET_PARAMETER, 1000000000000000, [-2147483648, 0, 2147483647, 1000000000000000]),
+
+            # No limits at all
+            (None, None, [-9999999999999999, -2147483648, -1, 0, 123, 2147483647, 9999999999999999]),
+
             # min_value only
-            (2, None, [2, 3, 99999]),
-            (-3, None, [-3, -2, -1, 0, 1, 99999]),
+            (2, None, [2, 3, 2147483647, 9999999999999999]),
+            (-3, None, [-3, -2, -1, 0, 1, 2147483647, 9999999999999999]),
+            (-1000000000000000, None, [-1000000000000000, -2147483648, 9999999999999999]),
+
             # max_value only
-            (None, 10, [-99999, -1, 0, 9, 10]),
-            (None, -10, [-99999, -11, -10]),
+            (None, 10, [-9999999999999999, -2147483648, -1, 0, 9, 10]),
+            (None, -10, [-9999999999999999, -2147483648, -11, -10]),
+            (None, 1000000000000000, [-9999999999999999, 2147483647, 1000000000000000]),
+
             # min_value and max_value
             (0, 10, [0, 1, 2, 9, 10]),
             (-10, -1, [-10, -9, -2, -1]),
@@ -60,21 +84,44 @@ class IntegerValidatorTest:
     )
     def test_integer_value_range_valid(min_value, max_value, input_data_list):
         """ Test IntegerValidator with range requirements with a list of valid integers. """
-        validator = IntegerValidator(min_value=min_value, max_value=max_value)
+        # Set validator parameters (use defaults if unset)
+        validator_args = {}
+        if min_value is not UNSET_PARAMETER:
+            validator_args['min_value'] = min_value
+        if max_value is not UNSET_PARAMETER:
+            validator_args['max_value'] = max_value
+
+        validator = IntegerValidator(**validator_args)
+
+        # Test validator for every integer in the list
         for input_data in input_data_list:
             assert validator.validate(input_data) == input_data
 
     @staticmethod
     @pytest.mark.parametrize(
-        'min_value, max_value, input_data_list', [
+        'min_value, max_value, input_data_list',
+        [
+            # Use default min_value and max_value (allows 32 bit integers only)
+            (UNSET_PARAMETER, UNSET_PARAMETER, [-1000000000000000, -2147483649, 2147483648, 1000000000000000]),
+
+            # Only set min_value, use default max_value
+            (-1000000000000000, UNSET_PARAMETER, [-1000000000000001, 2147483648, 1000000000000000]),
+
+            # Only set max_value, use default min_value
+            (UNSET_PARAMETER, 1000000000000000, [-1000000000000000, -2147483649, 1000000000000001]),
+
             # min_value only
-            (2, None, [-2, -1, 0, 1]),
-            (-3, None, [-5, -4]),
+            (2, None, [-99999999999, -2147483648, -1, 0, 1]),
+            (-3, None, [-99999999999, -2147483648, -5, -4]),
+            (-1000000000000000, None, [-1000000000000001]),
+
             # max_value only
-            (None, 10, [11, 12]),
-            (None, -10, [-9, 0, 9, 10, 11]),
+            (None, 10, [11, 12, 2147483647, 99999999999]),
+            (None, -10, [-9, 0, 9, 10, 2147483647, 99999999999]),
+            (None, 1000000000000000, [1000000000000001]),
+
             # min_value and max_value
-            (0, 10, [-2, -1, 11, 12]),
+            (0, 10, [-99999999999, -2147483648, -2, -1, 11, 12, 2147483647, 99999999999]),
             (-10, -1, [-11, 0, 1, 10]),
             (-2, 2, [-4, -3, 3, 4]),
             (1, 1, [-1, 0, 2]),
@@ -82,13 +129,23 @@ class IntegerValidatorTest:
     )
     def test_integer_value_range_invalid(min_value, max_value, input_data_list):
         """ Test IntegerValidator with range requirements with a list of invalid integers. """
-        validator = IntegerValidator(min_value=min_value, max_value=max_value)
+        # Set validator parameters (use defaults if unset)
+        validator_args = {}
+        if min_value is not UNSET_PARAMETER:
+            validator_args['min_value'] = min_value
+        if max_value is not UNSET_PARAMETER:
+            validator_args['max_value'] = max_value
+
+        validator = IntegerValidator(**validator_args)
 
         # Construct error dict with min_value and/or max_value, depending on which is specified
         expected_error_dict = {'code': 'number_range_error'}
-        expected_error_dict.update({'min_value': min_value} if min_value is not None else {})
-        expected_error_dict.update({'max_value': max_value} if max_value is not None else {})
+        if min_value is not None:
+            expected_error_dict['min_value'] = min_value if min_value is not UNSET_PARAMETER else -2147483648
+        if max_value is not None:
+            expected_error_dict['max_value'] = max_value if max_value is not UNSET_PARAMETER else 2147483647
 
+        # Test validator for every integer in the list
         for input_data in input_data_list:
             with pytest.raises(NumberRangeError) as exception_info:
                 validator.validate(input_data)
@@ -98,15 +155,19 @@ class IntegerValidatorTest:
 
     @staticmethod
     @pytest.mark.parametrize(
-        'input_data, expected_output', [
+        'input_data, expected_output',
+        [
             # Actual integers should still work of course
             (0, 0),
             (42, 42),
             (-123, -123),
+
             # Integers as strings
             ('0', 0),
             ('42', 42),
             ('-123', -123),
+            ('2147483647', 2147483647),
+            ('-2147483648', -2147483648),
         ]
     )
     def test_allow_strings_valid(input_data, expected_output):
@@ -132,12 +193,42 @@ class IntegerValidatorTest:
     def test_allow_strings_with_invalid_strings(input_data):
         """ Test that IntegerValidator with allow_strings=True raises exceptions on invalid (non-numeric) strings as input. """
         validator = IntegerValidator(allow_strings=True)
+
         with pytest.raises(InvalidIntegerError) as exception_info:
             validator.validate(input_data)
+
         assert exception_info.value.to_dict() == {
             'code': 'invalid_integer',
         }
 
+    @staticmethod
+    @pytest.mark.parametrize('input_data', ['-999999999999', '-2147483649', '2147483648', '999999999999'])
+    def test_allow_strings_with_default_value_range_invalid(input_data):
+        """
+        Test that IntegerValidator with allow_strings=True and default min_value/max_value raises exceptions for integers
+        outside these values (i.e. integers not fitting into 32 bits).
+        """
+        validator = IntegerValidator(allow_strings=True)
+
+        with pytest.raises(NumberRangeError) as exception_info:
+            validator.validate(input_data)
+
+        assert exception_info.value.to_dict() == {
+            'code': 'number_range_error',
+            'min_value': IntegerValidator.DEFAULT_MIN_VALUE,
+            'max_value': IntegerValidator.DEFAULT_MAX_VALUE,
+        }
+
+    @staticmethod
+    def test_allow_strings_without_value_range():
+        """ Test IntegerValidation with allow_strings=True and with min_value=None, max_value=None. """
+        validator = IntegerValidator(min_value=None, max_value=None, allow_strings=True)
+
+        # Valid input
+        assert validator.validate('0') == 0
+        assert validator.validate('-99999999999999') == -99999999999999
+        assert validator.validate('99999999999999') == 99999999999999
+
     @staticmethod
     def test_allow_strings_with_value_range():
         """ Test IntegerValidation with allow_strings=True and a value range. """
